@@ -6,18 +6,18 @@
 products <- function(reaction){
   # Identifies if stoichiometric reaction is not reversible. In this case:
   if (grepl("<=>",reaction)){
-    products <- unlist(strsplit(reaction,"<=>"))
-  }
-  # In contrary case:
-  else {
-    products <- unlist(strsplit(reaction,"=>"))[2]
+    products <- unlist(strsplit(reaction,"[[:blank:]]*<=>[[:blank:]]*"))
+  }else {
+    products <- unlist(strsplit(reaction,"[[:blank:]]*=>[[:blank:]]*"))[2]
   }
+
   # Split independient reactants
   products <- unlist(strsplit(products,"[[:blank:]]\\+[[:blank:]]"))
-  products <- gsub("^[[:blank:]]","",products)
-  products <- gsub("[[:blank:]]$","",products)
+  products <- gsub("^[[:blank:]]*","",products)
+  products <- gsub("[[:blank:]]*$","",products)
   # Use a regex to extract stoichiometric coefficients and separate the metabolite name
-  products <- gsub("^[[:digit:]]+[[:punct:]]?[[:digit:]]?[[:digit:]]?[[:blank:]]","",products)
-  return(products)
+  products <- gsub("^[[:digit:]][[:graph:]]*[[:blank:]]+","",products)
+  
+  return(products[!is.na(products)])
 }
 
